@@ -3,6 +3,7 @@ Set up the routes and WSGI Middleware used by TiddlySpace.
 """
 
 from tiddlyweb.web.negotiate import Negotiate
+from tiddlyweb.web.wsgi import HTMLPresenter
 
 from tiddlywebplugins.prettyerror import PrettyHTTPExceptor
 from tiddlywebplugins.utils import replace_handler
@@ -13,6 +14,7 @@ from tiddlywebplugins.tiddlyspace.csrf import CSRFProtector
 from tiddlywebplugins.tiddlyspace.handler import (home, friendly_uri,
         get_identities, get_space_tiddlers)
 from tiddlywebplugins.tiddlyspace.profiles import add_profile_routes
+from tiddlywebplugins.tiddlyspace.repudiator import Repudiator
 from tiddlywebplugins.tiddlyspace.safemode import safe_mode
 from tiddlywebplugins.tiddlyspace.spaces import add_spaces_routes
 
@@ -47,3 +49,11 @@ def establish_www(config):
         config['server_response_filters'].insert(
                 config['server_response_filters'].
                 index(PrettyHTTPExceptor) + 1, AllowOrigin)
+
+    if Repudiator not in config['server_response_filters']:
+        config['server_response_filters'].insert(
+                config['server_response_filters'].
+                index(PrettyHTTPExceptor) + 1, Repudiator)
+
+    if HTMLPresenter in config['server_response_filters']:
+        config['server_response_filters'].remove(HTMLPresenter)
